
<!---
FrozenIsBool True
-->

##Example

It is possible to 'reset' an instance with the default value
defined at the level of the class.
Note that the mutable variables that are initiated at the level of the class keeps
their ongoing value (as MyShareList). Also note that there is a setDefaultMutable that 
init all the mutables variables in the instance, if wanted.
